<?php
/**
 * Customizer option for social share
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-social-share
 */

namespace EPIC\SS;

use Jeg\Customizer\Customizer;

/**
 * Class SS Customizer
 *
 * @package EPIC\SS
 */
class Ss_Customizer {

	/**
	 * Post ID
	 *
	 * @var int
	 */
    private $post_id;

    /**
     * Hold redirect tag data
     *
     * @var array
     */
    private $redirect_tag = array();

	/**
	 * Ss_Meta_Box constructor.
	 */
	public function __construct() {
		add_action( 'jeg_register_customizer_option', array( $this, 'register_lazy_section' ), 91 );
		add_filter( 'jeg_register_lazy_section', array( $this, 'load_customizer' ) );
        add_action( 'customize_preview_init', array( $this, 'customize_preview_init' ) );
	}

	/**
	 * Init customizer preview
	 */
	public function customize_preview_init() {
        add_action( 'wp_enqueue_scripts' , array( $this, 'load_script' ), 99 );
	}

	/**
	 * Load necessary script
	 */
	public function load_script() {
		global $wp_query;

        if ( $wp_query->post ) {
            $this->post_id = $wp_query->post->ID;
        }

        $this->setup_redirect_tag();

		wp_enqueue_style( 'vex', EPIC_SS_URL . '/assets/css/admin/vex.css', null, EPIC_SS_VERSION );
		wp_enqueue_style( 'epic-customizer', EPIC_SS_URL . '/assets/css/admin/customizer.css', null, EPIC_SS_VERSION );

		wp_enqueue_script( 'vex', EPIC_SS_URL . '/assets/js/admin/vex.combined.min.js', array( 'jquery' ), EPIC_SS_VERSION, true );
		wp_enqueue_script( 'epic-customizer-redirect', 		EPIC_SS_URL . '/assets/js/admin/redirect.customizer.js', array( 'jquery', 'customize-preview' ), EPIC_SS_VERSION, true );

        wp_localize_script( 'epic-customizer-redirect', 'epic_redirect', $this->redirect_tag );
	}

	/**
	 * Setup customizer redirect tag
	 */
	public function setup_redirect_tag() {
		$this->redirect_tag['setting'] = array (
            'change_notice' => esc_html__('Change you made not showing on this page. Do you want to be redirected to the appropriate page to see the change you just made?', 'epic-ss'),
            'yes' => esc_html__('Yes', 'epic-ss'),
        );

        $this->redirect_tag['single_post_tag'] = array(
            'url'       => $this->get_random_single_post_url(),
            'flag'      => is_single(),
            'text'      => esc_html__( 'Single Post', 'epic-ss' ),
        );
    }

	/**
	 * Get random single post URL
	 *
	 * @return false|null|string
	 */
    public function get_random_single_post_url() {
        $posts = get_posts( 'orderby=rand&numberposts=1' );

        if ( $posts ) {
            return get_permalink( $posts[0]->ID );
        } else {
            return null;
        }
    }

	/**
	 * Register Lazy Customizer
	 */
	public function register_lazy_section() {
		$customizer = Customizer::get_instance();

		$customizer->add_panel(array(
		    'id'          => 'epic_ss_panel',
			'title'       => esc_html__( 'EPIC : Social Share Setting', 'epic-ss' ),
		    'description' => '',
		    'priority' 	  => 171
	    ));

		$customizer->add_section(array(
			'id'       => 'epic_ss_position',
			'title'    => esc_html__( 'Share Bar Setting', 'epic-ss' ),
			'panel'    => 'epic_ss_panel',
			'priority' => 171,
			'type'     => 'jeg-lazy-section',
		));

		$customizer->add_section(array(
			'id'       => 'epic_ss_icon',
			'title'    => esc_html__( 'Share Icon Setting', 'epic-ss' ),
			'panel'    => 'epic_ss_panel',
			'priority' => 171,
			'type'     => 'jeg-lazy-section',
		));
	}

	/**
	 * Load Customizer
	 *
	 * @param array $result Array list of section.
	 *
	 * @return mixed
	 */
	public function load_customizer( $result ) {
		$result['epic_ss_position'][] = EPIC_SS_DIR . '/includes/options/position.php';
		$result['epic_ss_icon'][] 	  = EPIC_SS_DIR . '/includes/options/icon.php';

		return $result;
	}
}
