<?php
/**
 * Elementor integration
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-social-share
 */

namespace EPIC\SS;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;

/**
 * Class Ss_Elementor
 *
 * @package EPIC\SS
 */
class Ss_Elementor extends Widget_Base {

	/**
	 * @var Ss
	 */
	private $ss_instance;

	/**
	 * Ss_Elementor constructor.
	 */
	public function __construct( array $data = [], $args = null ) {
		parent::__construct( $data, $args );

		$this->ss_instance = Ss::get_instance();
	}

	/**
	 * Register share option
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'general_section',
			[
				'label' => esc_html__( 'General', 'epic-ss' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		foreach ( $this->ss_instance->element_option() as $option ) {
			$this->parse_control_option( $option );
		}

		$this->end_controls_section();
	}

	/**
	 * Render share element
	 */
	protected function render() {
		$settings = $this->get_settings();
        $style  = apply_filters('epic_elementor_share_style', Ss::get_option( 'content_share_style', 'colored' ), $position = null, $element = 'render' );


        switch ( $settings['type'] ) {
			case '1' :
				$output = $this->ss_instance->share_type_1(null, 'render');
				break;

			case '2' :
				$output = $this->ss_instance->share_type_2(null, 'render');
				break;
		}

		echo
			'<div class="jeg_share_shortcode_container">
				<div class="jeg_share_button ' . $style . ' clearfix">
					' . $output . '
				</div>
			</div>';

	}

	/**
	 * Parse share option
	 *
	 * @param $option
	 */
	private function parse_control_option( $option ) {
		$option['heading'] = isset( $option['heading'] ) ? $option['heading'] : '';

		switch ( $option['type'] ) {
			case 'textfield':
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::TEXT,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'textarea':
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::TEXTAREA,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'colorpicker' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::COLOR,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'dropdown' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::SELECT,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'options'     => $option['value'],
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'iconpicker' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::ICON,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'radioimage' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::CHOOSE,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'options'     => $this->parse_radioimage_option( $option['value'], $option['param_name'] ),
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'attach_image' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::MEDIA,
						'default'     => [
							'url' => isset( $option['default'] ) ? $option['default'] : '',
						],
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'checkbox' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::SWITCHER,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'textarea_html' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::CODE,
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'language'    => 'html',
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'slider' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::SLIDER,
						'default'     => [
							'size' => isset( $option['default'] ) ? $option['default'] : 0,
						],
						'range'       => [
							'px' => [
								'min'  => $option['min'],
								'max'  => $option['max'],
								'step' => $option['step'],
							],
						],
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'number' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => Controls_Manager::NUMBER,
						'default'     => isset( $option['default'] ) ? $option['default'] : 0,
						'min'         => $option['min'],
						'max'         => $option['max'],
						'step'        => $option['step'],
						'label_block' => true,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : ''
					]
				);
				break;

			case 'select' :
				$select = array();

				if ( isset( $option['value'] ) ) {
					$select = $option['value'];

					if ( isset( $option['multiple'] ) ) {
						$select = wp_json_encode( $select );
					}
				}

				if ( isset( $option['options'] ) ) {
					$select = call_user_func( $option['options'] );
					$select = wp_json_encode( $select );
				}

				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => 'dynamicselect',
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'label_block' => true,
						'multiple'    => isset( $option['multiple'] ) ? $option['multiple'] : 1,
						'ajax'        => isset( $option['ajax'] ) ? $option['ajax'] : '',
						'nonce'       => isset( $option['nonce'] ) ? $option['nonce'] : '',
						'retriever'   => isset( $option['options'] ) ? $option['options'] : '',
						'options'     => $select,
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : '',
						'description' => isset( $option['description'] ) ? $option['description'] : '',
					]
				);
				break;

			case 'alert' :
				$this->add_control(
					$option['param_name'],
					[
						'label'       => $option['heading'],
						'type'        => 'alert',
						'default'     => isset( $option['default'] ) ? $option['default'] : '',
						'label_block' => true,
						'description' => isset( $option['description'] ) ? $option['description'] : '',
						'condition'   => isset( $option['dependency'] ) ? $this->parse_dependency_option( $option['dependency'] ) : ''
					]
				);
				break;

			default:
				break;
		}
	}

	/**
	 * Dependency option handler
	 *
	 * @param $value
	 *
	 * @return array
	 */
	public function parse_dependency_option( $value ) {
		return array( $value['element'] => ( $value['value'] === 'true' ) ? 'yes' : $value['value'] );
	}

	/**
	 * Get element name
	 *
	 * @return string
	 */
	public function get_name() {
		return 'epic_ss_element';
	}

	/**
	 * Get element title
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Epic Social Share', 'epic-ss' );
	}

	/**
	 * Get element category
	 *
	 * @return array
	 */
	public function get_categories() {
		return [ 'epic-ss-element' ];
	}
}
