<?php

use EPIC\SS\Ss;
use Jeg\Form\Form_Widget;

class Ss_Widget extends \WP_Widget {

	/**
	 * @var Ss
	 */
	private $ss_instance;

	/**
	 * Ss_Widget constructor.
	 */
	function __construct() {
		parent::__construct(
			'Ss_Widget',
			esc_html__('Epic Social Share', 'epic-ss'),
			array( 'description' => esc_html__( 'Social share widget element.', 'epic-ss' ), )
		);

		$this->ss_instance = Ss::get_instance();
	}

	/**
	 * Echoes the widget content.
	 *
	 * Sub-classes should over-ride this function to generate their widget code.
	 *
	 * @since 2.8.0
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance The settings for the particular instance of the widget.
	 */
	public function widget( $args, $instance ) {
		echo jeg_sanitize_output( $args['before_widget'] );

		$output = '';

		if ( is_front_page() ) {
			$this->ss_instance->set_home_flag( true );
		}

        $instance['type'] = isset( $instance['type'] ) ? $instance['type'] : '1';
        $style  = apply_filters('epic_widget_share_style', Ss::get_option( 'content_share_style', 'colored' ), $position = null, $element = 'widget' );

		switch ( $instance['type'] ) {
			case '1' :
				$output = $this->ss_instance->share_type_1(null, 'widget');
				break;

			case '2' :
				$output = $this->ss_instance->share_type_2(null, 'widget');
				break;
		}

		echo '<div class="jeg_share_shortcode_container">
				<div class="jeg_share_button ' . $style . ' clearfix">
					' . $output . '
				</div>
			</div>';

		echo jeg_sanitize_output( $args['after_widget'] );
	}

	/**
	 * Outputs the settings update form.
	 *
	 * @since 2.8.0
	 *
	 * @param array $instance Current settings.
	 * @return string Default return is 'noform'.
	 */
	public function form( $instance ) {
		$id       = $this->get_field_id( 'widget_social_share' );
		$options  = $this->ss_instance->element_option();
		$segments = $this->prepare_segments();
		$fields   = $this->prepare_fields( $instance, $options );

		Form_Widget::render_form($id, $segments, $fields);
	}

	/**
	 * Prepare segment
	 *
	 * @return array
	 */
	public function prepare_segments() {
		$segments = array();

		$segments[] = array(
			'id'   => 'general',
			'name' => esc_html__( 'General', 'epic-ss' )
		);

		return $segments;
	}

	/**
	 * Get default option group
	 *
	 * @return string
	 */
	public function get_default_group() {
		return esc_html__( 'General', 'epic-ss' );
	}

	/**
	 * Prepare fields
	 *
	 * @param $instance
	 * @param $fields
	 *
	 * @return array
	 */
	public function prepare_fields( $instance, $fields ) {
		$setting = array();

		foreach ( $fields as $key => $field ) {

			$setting[ $key ]              = array();
			$setting[ $key ]['id']        = $field['param_name'];
			$setting[ $key ]['fieldID']   = $this->get_field_id( $field['param_name'] );
			$setting[ $key ]['fieldName'] = $this->get_field_name( $field['param_name'] );
			$setting[ $key ]['type']      = $this->convert_type( $field['type'] );

			$setting[ $key ]['title']       = isset( $field['heading'] ) ? $field['heading'] : '';
			$setting[ $key ]['description'] = isset( $field['description'] ) ? $field['description'] : '';
			$setting[ $key ]['segment']     = isset( $field['group'] ) ? sanitize_title_with_dashes( $field['group'] ) : sanitize_title_with_dashes( $this->get_default_group() );
			$setting[ $key ]['default']     = isset( $field['std'] ) ? $field['std'] : '';
			$setting[ $key ]['priority']    = isset( $field['priority'] ) ? $field['priority'] : 10;
			$setting[ $key ]['options']     = isset( $field['value'] ) ? $field['value'] : array();

			if ( $field['type'] === 'slider' || $field['type'] === 'number' ) {
				$setting[ $key ]['options'] = array(
					'min'  => $field['min'],
					'max'  => $field['max'],
					'step' => $field['step'],
				);
			}


			$setting[ $key ]['multiple']  = isset( $field['multiple'] ) ? $field['multiple'] : 1;
			$setting[ $key ]['ajax']      = isset( $field['ajax'] ) ? $field['ajax'] : '';
			$setting[ $key ]['nonce']     = isset( $field['nonce'] ) ? $field['nonce'] : '';
			$setting[ $key ]['value']     = $this->get_value( $field['param_name'], $instance, $setting[ $key ]['default'] );
			$setting[ $key ]['fields']    = isset( $field['fields'] ) ? $field['fields'] : array();
			$setting[ $key ]['row_label'] = isset( $field['row_label'] ) ? $field['row_label'] : array();
		}

		return $setting;
	}

	/**
	 * Convert option type
	 *
	 * @param $type
	 *
	 * @return string
	 */
	public function convert_type( $type ) {
		switch ( $type ) {
			case 'textfield':
				$type = 'text';
				break;

			case 'colorpicker':
				$type = 'color';
				break;

			case 'dropdown':
				$type = 'select';
				break;

			case 'textarea_html':
				$type = 'textarea';
				break;

			case 'attach_image':
				$type = 'image';
				break;
		}

		return $type;
	}

	/**
	 * Get widget value
	 *
	 * @param $id
	 * @param $value
	 * @param $default
	 *
	 * @return mixed
	 */
	public function get_value( $id, $value, $default ) {
		if ( isset( $value[ $id ] ) ) {
			return $value[ $id ];
		} else {
			return $default;
		}
	}
}
