<?php
/**
 * WPBakery integration
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-social-share
 */

namespace EPIC\SS;

/**
 * Class Ss_Wpbakery
 *
 * @package EPIC\SS
 */
class Ss_Wpbakery {

	/**
	 * Singleton initialization
	 *
	 * @var Ss_Wpbakery
	 */
	private static $instance;

	/**
	 * @var Ss
	 */
	private $ss_instance;

	/**
	 * @return Ss_Wpbakery
	 */
	public static function get_instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Ss_Wpbakery constructor.
	 */
	private function __construct() {
		add_action( 'init', array( $this, 'map_vc' ) );
	}

	/**
	 * Register share element
	 */
	public function map_vc() {
		$this->ss_instance = Ss::get_instance();

		if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {

			$args = array(
				'base'        => 'epic_ss_element',
				'params'      => $this->get_options(),
				'name'        => esc_html__( 'Epic Social Share', 'epic-ss' ),
				'category'    => esc_html__( 'Epic Social Share', 'epic-ss' ),
				'icon'        => '',
				'description' => esc_html__( 'Epic Social Share', 'epic-ss' ),
			);

			vc_map( $args );
		}

		add_shortcode( 'epic_ss_element', array( $this, 'generate_shortcode' ) );
	}

	/**
	 * Build share shortcode
	 *
	 * @param $attr
	 *
	 * @return string
	 */
	public function generate_shortcode( $attr ) {
		$output = '';
		$attr = shortcode_atts(
			array(
				'type' => '1'
			),
		$attr );
        $style  = apply_filters('epic_vc_share_style', Ss::get_option( 'content_share_style', 'colored' ), $position = null, $element = 'generate_shortcode' );

        switch ( $attr['type'] ) {
			case '1' :
				$output = $this->ss_instance->share_type_1(null, 'generate_shortcode');
				break;

			case '2' :
				$output = $this->ss_instance->share_type_2(null, 'generate_shortcode');
				break;
		}

		return
			'<div class="jeg_share_shortcode_container">
				<div class="jeg_share_button ' . $style . ' clearfix">
					' . $output . '
				</div>
			</div>';
	}

	/**
	 * Get share option
	 *
	 * @return array
	 */
	protected function get_options() {
		$options = $this->ss_instance->element_option();

		foreach ( $options as &$option ) {
			if ( 'dropdown' === $option['type'] ) {
				$option['value'] = array_flip( $option['value'] );
			}
		}

		return $options;
	}
}
